cmoncrawl.processor.pipeline.streamer.StreamerFileHTML.get\_file\_name
======================================================================

.. currentmodule:: cmoncrawl.processor.pipeline.streamer

.. automethod:: StreamerFileHTML.get_file_name